@@ -54,11 +54,11 @@ App::Dochazka::REST::ResourceDefs - Resource definitions
 
 =head1 VERSION
 
-Version 0.400
+Version 0.401
 
 =cut
 
-our $VERSION = '0.400';
+our $VERSION = '0.401';
 
 
 
@@ -418,6 +418,11 @@ EOH
         },
         description => 'GET, PUT, or DELETE an activity object by its AID',
         documentation => <<'EOH',
+=pod
+
+This resource allows the user to GET, PUT, or DELETE an activity object by its
+AID.
+
 =over
 
 =item * GET
@@ -516,6 +521,11 @@ EOH
         },
         description => 'GET, PUT, or DELETE an activity object by its code',
         documentation => <<'EOH',
+=pod
+
+With this resource, a user can GET, PUT, or DELETE an activity object by its
+code.
+
 =over
 
 =item * GET
@@ -617,6 +627,9 @@ EOH
         documentation => <<'EOH',
 =pod
 
+With this resource, we can retrieve (GET) and edit (POST) our own employee
+profile.
+
 =over
 
 =item * GET
@@ -701,6 +714,11 @@ EOH
         },
         description => 'GET: look up employee (exact match); PUT: update existing employee; DELETE: delete employee',
         documentation => <<'EOH',
+=pod
+
+With this resource, we can look up an employee by exact match (GET),
+update an existing employee (PUT), or delete an employee (DELETE).
+
 =over
 
 =item * GET
@@ -782,6 +800,11 @@ EOH
         },
         description => "Retrieves (GET), updates/inserts (PUT), and/or deletes (DELETE) the employee specified by the ':nick' parameter",
         documentation => <<'EOH',
+=pod
+
+Retrieves (GET), updates/inserts (PUT), and/or deletes (DELETE) the employee
+specified by the ':nick' parameter.
+
 =over
 
 =item * GET
@@ -871,6 +894,9 @@ EOH
         documentation => <<'EOH',
 =pod
 
+With this resource, we can retrieve (GET) and/or edit (POST) our own employee
+profile.
+
 =over
 
 =item * GET
@@ -974,6 +1000,10 @@ EOH
         documentation => <<'EOH',
 =pod
 
+Retrieves entire history of privilege level changes for employee with the given
+EID (GET); or, with an appropriate content body, adds (POST) a record to
+employee\'s privhistory.
+
 =over
 
 =item * GET
@@ -1015,6 +1045,10 @@ EOH
         documentation => <<'EOH',
 =pod
 
+Retrieves entire history of schedule changes for employee with the given EID
+(GET); or, with an appropriate content body, adds (POST) a record to
+employee\'s schedule history.
+
 =over
 
 =item * GET
@@ -1097,6 +1131,10 @@ EOH
         documentation => <<'EOH',
 =pod
 
+Retrieves entire history of privilege level changes for employee with the given
+nick (GET); or, with an appropriate content body, adds (PUT) a record to
+employee\'s privhistory.
+
 =over
 
 =item * GET
@@ -1138,6 +1176,10 @@ EOH
         documentation => <<'EOH',
 =pod
 
+Retrieves entire history of schedule changes for employee with the given nick
+(GET); or, with an appropriate content body, adds (PUT) a record to employee\'s
+schedule history.
+        
 =over
 
 =item * GET
@@ -1222,6 +1264,9 @@ EOH
         documentation => <<'EOH',
 =pod
 
+Retrieves (GET) or deletes (DELETE) a single privilege history record by its
+PHID.
+
 =over
 
 =item * GET
@@ -1255,6 +1300,9 @@ EOH
         documentation => <<'EOH',
 =pod
 
+Retrieves (GET) or deletes (DELETE) a single schedule history record by its
+SHID.
+
 =over
 
 =item * GET
@@ -1289,7 +1337,10 @@ EOH
 
 This resource retrieves the "privhistory", or history of changes in
 privilege level, of the present employee. Optionally, the listing can be
-limited to a specific tsrange such as "[2014-01-01, 2014-12-31)".
+limited to a specific tsrange such as 
+
+    "[2014-01-01, 2014-12-31)"
+
 EOH
     },
 
@@ -1310,7 +1361,10 @@ EOH
 
 This resource retrieves the "schedule history", or history of changes in
 schedule, of the present employee. Optionally, the listing can be
-limited to a specific tsrange such as "[2014-01-01, 2014-12-31)".
+limited to a specific tsrange such as 
+
+    "[2014-01-01, 2014-12-31)"
+
 EOH
     },
 
@@ -1399,11 +1453,16 @@ EOH
         },
         description => 'GET, PUT, or DELETE an interval object by its iid',
         documentation => <<'EOH',
+=pod
+
+This resource makes it possible to GET, PUT, or DELETE an interval object by
+its IID.
+
 =over
 
 =item * GET
 
-Retrieves an interval object by its iid.
+Retrieves an interval object by its IID.
 
 =item * PUT
 
@@ -1411,7 +1470,11 @@ Updates the interval object whose iid is specified by the ':iid' URI parameter.
 The fields to be updated and their new values should be sent in the request
 body, e.g., like this:
 
-    { "eid" : 34, "aid" : 1, "intvl" : '[ 2014-11-18 08:00, 2014-11-18 12:00 )' }
+    { 
+        "eid" : 34, 
+        "aid" : 1, 
+        "intvl" : '[ 2014-11-18 08:00, 2014-11-18 12:00 )' 
+    }
 
 =item * DELETE
 
@@ -1613,8 +1676,13 @@ EOH
         validations => {
             'lid' => 'Int',
         },
-        description => 'GET, PUT, or DELETE an lock object by its lid',
+        description => 'GET, PUT, or DELETE an lock object by its LID',
         documentation => <<'EOH',
+=pod
+
+This resource makes it possible to GET, PUT, or DELETE an lock object by its
+LID.
+
 =over
 
 =item * GET
@@ -1627,7 +1695,10 @@ Updates the lock object whose lid is specified by the ':lid' URI parameter.
 The fields to be updated and their new values should be sent in the request
 body, e.g., like this:
 
-    { "eid" : 34, "intvl" : '[ 2014-11-18 00:00, 2014-11-18 24:00 )' }
+    { 
+        "eid" : 34, 
+        "intvl" : '[ 2014-11-18 00:00, 2014-11-18 24:00 )' 
+    }
 
 =item * DELETE
 
@@ -2003,6 +2074,8 @@ EOH
         documentation => <<'EOH',
 =pod
 
+This resource makes it possible to GET, PUT, or DELETE a schedule by its SID.
+
 =over
 
 =item * GET
